%global revision 1994cc8

Summary:	The BOINC client core
Name:		boinc-client
Version:	7.2.33
Release:	3.git%{revision}%{?dist}
License:	LGPLv2+
Group:		Applications/Engineering
URL:		http://boinc.berkeley.edu/
# The source for this package was pulled from upstream's vcs. Use the
# following commands to generate the tarball:
# git clone git://boinc.berkeley.edu/boinc-v2.git boinc-repo
# pushd boinc-repo
# git checkout client_release/7.2/7.2.33
# ./_autosetup
# ../trim . Trim all binaries and other unnecessary things.
# rm -rf .git*
# popd
# mv boinc-repo boinc
# tar -cJvf boinc-%%{version}.tar.xz boinc
Source0:	boinc-%{version}.tar.xz
Source1:	boinc-client-init-d
Source2:	boinc-client-logrotate-d
Source3:	boinc-manager.desktop
Source4:	USAGE_FEDORA
Source5:	trim
#Create password file rw for group, this enables passwordless connection
#of manager from users of the boinc group.
#This won't be probably upstreamed as it might be unsafe for common usage
#without setting proper group ownership of the password file.
Patch0:		boinc-guirpcauth.patch
# Fix Italian locale broken directory
Patch1:		boinc-client-locale.patch
BuildRoot:	%(mktemp -ud %{_tmppath}/%{name}-%{version}-%{release}-XXXXXX)

Requires:	logrotate
Requires(post): chkconfig
Requires(preun): chkconfig
Requires(preun): initscripts
Requires(postun): initscripts
Requires(pre):	shadow-utils

BuildRequires:	MySQL-python
BuildRequires:	sqlite-devel
BuildRequires:	curl-devel
BuildRequires:	desktop-file-utils
BuildRequires:	freeglut-devel
BuildRequires:	mesa-libGLU-devel
BuildRequires:	openssl-devel
BuildRequires:	wxGTK-devel
BuildRequires:	gettext
BuildRequires:	mysql-devel
BuildRequires:	libXmu-devel
BuildRequires:	libjpeg-devel
BuildRequires:	docbook2X
BuildRequires:	xcb-util-devel
BuildRequires:	libnotify-devel
BuildRequires:	gtk2-devel
BuildRequires:	libXScrnSaver-devel

%description
The Berkeley Open Infrastructure for Network Computing (BOINC) is an open-
source software platform which supports distributed computing, primarily in
the form of "volunteer" computing and "desktop Grid" computing.  It is well
suited for problems which are often described as "trivially parallel".  BOINC
is the underlying software used by projects such as SETI@home, Einstein@Home,
ClimatePrediciton.net, the World Community Grid, and many other distributed
computing projects.

This package installs the BOINC client software, which will allow your
computer to participate in one or more BOINC projects, using your spare
computer time to search for cures for diseases, model protein folding, study
global warming, discover sources of gravitational waves, and many other types
of scientific and mathematical research.

%package -n boinc-manager
Summary:	GUI to control and monitor %{name}
Group:		Applications/Engineering

Requires:	hicolor-icon-theme
Requires:	%{name} = %{version}-%{release}

%description -n boinc-manager
The BOINC Manager is a graphical monitor and control utility for the BOINC
core client. It gives a detailed overview of the state of the client it is
monitoring. The BOINC Manager has two modes of operation, the "Simple View" in
which it only displays the most important information and the "Advanced View"
in which all information and all control elements are available.

%package devel
Summary:	Development files for %{name}
Group:		Development/Libraries

Requires:	%{name} = %{version}-%{release}
Requires:	openssl-devel
Requires:	mysql-devel

%description devel
This package contains development files for %{name}.

%package static
Summary:	Static libraries for %{name}
Group:		Development/Libraries

Requires:	%{name}-devel = %{version}-%{release}

%description static
This package contains static libraries for %{name}.

%package doc
Summary:	Documentation files for %{name}
Group:		Documentation
BuildArch:	noarch

Requires:	%{name} = %{version}-%{release}

%description doc
This package contains documentation files for %{name}.

%prep
%setup -q -n boinc
%patch0
%patch1

# fix utf8
iconv -f ISO88591 -t UTF8 < checkin_notes_2004 > checkin_notes_2004.utf8
touch -r checkin_notes_2004 checkin_notes_2004.utf8
mv checkin_notes_2004.utf8 checkin_notes_2004

iconv -f ISO88591 -t UTF8 < checkin_notes_2005 > checkin_notes_2005.utf8
touch -r checkin_notes_2005 checkin_notes_2005.utf8
mv checkin_notes_2005.utf8 checkin_notes_2005

iconv -f ISO88591 -t UTF8 < checkin_notes_2009 > checkin_notes_2009.utf8
touch -r checkin_notes_2009 checkin_notes_2009.utf8
mv checkin_notes_2009.utf8 checkin_notes_2009

iconv -f ISO88591 -t UTF8 < checkin_notes_2010 > checkin_notes_2010.utf8
touch -r checkin_notes_2010 checkin_notes_2010.utf8
mv checkin_notes_2010.utf8 checkin_notes_2010

iconv -f ISO88591 -t UTF8 < checkin_notes_2011 > checkin_notes_2011.utf8
touch -r checkin_notes_2011 checkin_notes_2011.utf8
mv checkin_notes_2011.utf8 checkin_notes_2011

%build
%ifarch %{ix86}
%global boinc_platform i686-pc-linux-gnu
%endif
%ifarch powerpc ppc
%global boinc_platform powerpc-linux-gnu
%endif
%ifarch powerpc64 ppc64
%global boinc_platform ppc64-linux-gnu
%endif

# Install user hints
install -p -m644 %{SOURCE4} .

%global confflags --disable-dependency-tracking --enable-dynamic-client-linkage --disable-server --disable-fcgi --enable-unicode --with-ssl --with-x STRIP=: DOCBOOK2X_MAN=/usr/bin/db2x_docbook2man

%if %{defined boinc_platform}
CXXFLAGS=`pkg-config gtk+-x11-2.0 --cflags --libs` %configure %{confflags} --with-boinc-platform=%{boinc_platform}
%else
CXXFLAGS=`pkg-config gtk+-x11-2.0 --cflags --libs` %configure %{confflags}
%endif

# Disable rpaths
sed -i 's|^hardcode_libdir_flag_spec=.*|hardcode_libdir_flag_spec=""|g' libtool
sed -i 's|^runpath_var=LD_RUN_PATH|runpath_var=DIE_RPATH_DIE|g' libtool

make %{?_smp_mflags}

%install
rm -rf $RPM_BUILD_ROOT
mkdir -p $RPM_BUILD_ROOT%{_datadir}/icons/hicolor/16x16/apps
mkdir -p $RPM_BUILD_ROOT%{_datadir}/icons/hicolor/32x32/apps
mkdir -p $RPM_BUILD_ROOT%{_datadir}/icons/hicolor/48x48/apps
mkdir -p $RPM_BUILD_ROOT%{_initrddir}
mkdir -p $RPM_BUILD_ROOT%{_localstatedir}/lib/boinc
mkdir -p $RPM_BUILD_ROOT%{_mandir}/man1
mkdir -p $RPM_BUILD_ROOT%{_sysconfdir}/logrotate.d/

make install INSTALL="%{__install} -p" DESTDIR=$RPM_BUILD_ROOT

pushd $RPM_BUILD_ROOT%{_bindir}

rm boinc
cat > boinc <<EOF
#!/bin/bash
# wrapper script that redirects stdout/stderr to correct log paths

# we allow multiple clients so that the client does not think there is another instance running (namely this wrapper)
%{_bindir}/boinc_client --allow_multiple_clients \$@ >> %{_localstatedir}/log/boinc.log 2>> %{_localstatedir}/log/boincerr.log 
EOF
chmod a+x boinc

# remove libtool archives
rm $RPM_BUILD_ROOT%{_libdir}/*.la

popd

# own init script and logrotate configuration file
rm -f $RPM_BUILD_ROOT%{_sysconfdir}/init.d/%{name}
install -p -m755 %{SOURCE1} $RPM_BUILD_ROOT%{_initrddir}/%{name}
install -p -m644 %{SOURCE2} $RPM_BUILD_ROOT%{_sysconfdir}/logrotate.d/%{name}

# icon
cp -p clientgui/res/boincmgr.16x16.png $RPM_BUILD_ROOT%{_datadir}/icons/hicolor/16x16/apps/boincmgr.png
cp -p clientgui/res/boincmgr.32x32.png $RPM_BUILD_ROOT%{_datadir}/icons/hicolor/32x32/apps/boincmgr.png
cp -p clientgui/res/boincmgr.48x48.png $RPM_BUILD_ROOT%{_datadir}/icons/hicolor/48x48/apps/boincmgr.png

desktop-file-install %{?_remove_encoding} --vendor fedora \
  --dir $RPM_BUILD_ROOT%{_datadir}/applications \
  %{SOURCE3}

%find_lang BOINC-Manager
%find_lang BOINC-Client

# bash-completion
install -Dp -m644 client/scripts/boinc.bash $RPM_BUILD_ROOT%{_sysconfdir}/bash_completion.d/boinc-client

%clean
rm -rf $RPM_BUILD_ROOT

%pre

# Create BOINC user and group
getent group boinc >/dev/null || groupadd -r boinc
getent passwd boinc >/dev/null || \
useradd -r -g boinc -d %{_localstatedir}/lib/boinc -s /sbin/nologin \
	-c "BOINC client account." boinc
exit 0

%post
/sbin/ldconfig
/sbin/chkconfig --add boinc-client

%preun
if [ $1 -eq 0 ]; then #if uninstalling, not only updating
	/sbin/service boinc-client stop
	/sbin/chkconfig --del boinc-client
fi

%postun
/sbin/ldconfig

if [ "$1" -ge "1" ] ; then
	/sbin/service boinc-client condrestart >/dev/null 2>&1 || :
fi


%post -n boinc-manager
touch --no-create %{_datadir}/icons/hicolor || :
if [ -x %{_bindir}/gtk-update-icon-cache ]; then
  %{_bindir}/gtk-update-icon-cache --quiet %{_datadir}/icons/hicolor || :
fi

%postun -n boinc-manager
touch --no-create %{_datadir}/icons/hicolor || :
if [ -x %{_bindir}/gtk-update-icon-cache ]; then
  %{_bindir}/gtk-update-icon-cache --quiet %{_datadir}/icons/hicolor || :
fi

%files -f BOINC-Client.lang
%defattr(-,root,root,-)
%config(noreplace) %{_sysconfdir}/logrotate.d/%{name}
%config(noreplace) %{_sysconfdir}/bash_completion.d/
%config(noreplace) %{_sysconfdir}/sysconfig/%{name}
%doc COPYING COPYRIGHT USAGE_FEDORA
%{_bindir}/boinc
%{_bindir}/boinc_client
%{_bindir}/boinccmd
%{_bindir}/switcher
%{_initrddir}/%{name}
%{_mandir}/man1/boinccmd.1.gz
%{_mandir}/man1/boinc.1.gz
%{_libdir}/*.so.*
%defattr(775,boinc,boinc,775)
%{_localstatedir}/lib/boinc/

%files doc
%defattr(-,root,root,-)
%doc checkin_notes checkin_notes_*

%files -n boinc-manager -f BOINC-Manager.lang
%defattr(-,root,root,-)
%{_bindir}/boincmgr
%{_bindir}/boincscr
%{_datadir}/applications/fedora-boinc-manager.desktop
%{_datadir}/icons/hicolor/16x16/apps/boincmgr.png
%{_datadir}/icons/hicolor/32x32/apps/boincmgr.png
%{_datadir}/icons/hicolor/48x48/apps/boincmgr.png
%{_mandir}/man1/boincmgr.1.gz

%files static
%defattr(-,root,root,-)
%{_libdir}/libboinc.a
%{_libdir}/libboinc_api.a
%{_libdir}/libboinc_crypt.a
%{_libdir}/libboinc_graphics2.a
%{_libdir}/libboinc_opencl.a

%files devel
%defattr(-,root,root,-)
%{_libdir}/*.so
%{_includedir}/boinc

%changelog
* Fri Feb 07 2014 Mattia Verga <mattia.verga@tiscali.it> - 7.2.33-3.git1994cc8
- Upgrade to 7.2.33 to pair with F20
- Clean up specfile

* Wed Apr 07 2010 Miloš Jakubíček <xjakub@fi.muni.cz> - 6.10.45-1.r21128svn
- Rebase the 6.10 branch to 6.10.45

* Thu Mar 11 2010 Miloš Jakubíček <xjakub@fi.muni.cz> - 6.10.36-1.r20845svn
- Rebase the 6.10 branch to 6.10.36

* Tue Feb 09 2010 Milos Jakubicek <xjakub@fi.muni.cz> - 6.10.33-1.r20470svn
- Rebase the 6.10 branch to 6.10.33
- Run with +10 niceness instead of +19 (resolves BZ#562883)

* Tue Dec 22 2009 Milos Jakubicek <xjakub@fi.muni.cz> - 6.10.25-1.r20004svn
- Rebase to 6.10 branch
- Use XZ for sources compression
- Added BR: sqlite-devel
- Dropped boinc-gcc44.patch (merged upstream)
- Dropped boinc-macbuild.patch (merged upstream)
- Fix owner/group of shared libraries

* Fri Aug 21 2009 Tomas Mraz <tmraz@redhat.com> - 6.6.37-4.r18632svn
- rebuilt with new openssl

* Fri Jul 24 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 6.6.37-3.r18632svn
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Tue Jul 21 2009 Milos Jakubicek <xjakub@fi.muni.cz> - 6.6.37-2.r18632svn
- Rebase to 6.6a branch (resolves BZ#477882)
- Ship shared libraries too, link client dynamically to them
- Dropped boinc-rsa.patch (merged upstream)
- Dropped boinc-client-6.4.5-event.patch (merged upstream)
- Dropped boinc-cuda.patch (merged upstream)
- Dropped boinc-gccflags.patch (merged upstream)
- Updated boinc-gcc44.patch (merged partially)
- Disable newly appeared standard rpaths
- Added short user guide exported from wiki as USAGE_FEDORA

* Sun Jul 19 2009 Milos Jakubicek <xjakub@fi.muni.cz> - 6.6.37-1.r18631svn
- Update to 6.6 branch
- Removed boinc-locales.patch (merged upstream)
- Added boinc-macbuild.patch to fix ppc/ppc64 build failure
- Fixed typo in upstream bugtracker link
- Fix SELinux issue in logrotate script, resolves BZ#498165

* Thu May 14 2009 Milos Jakubicek <xjakub@fi.muni.cz> - 6.4.7-11.r17542svn
- Condrestart the service after package update.
- Added R: initscripts (needed for /sbin/service), chkconfig R: moved to scriptlets.
